==> votca-xtp_1.6.4.orig.tar.gz: xtp-1.6.4/include/votca/xtp/qmmolecule.h <==
/*
 *            Copyright 2009-2019 The VOTCA Development Team
 *                       (http://www.votca.org)
 *
 *      Licensed under the Apache License, Version 2.0 (the "License")
 *
 * You may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *              http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */

#pragma once
#ifndef VOTCA_XTP_QMMOLECULE_H
#define VOTCA_XTP_QMMOLECULE_H

#include <votca/xtp/atomcontainer.h>
#include <votca/xtp/qmatom.h>

namespace votca {
namespace xtp {

class QMMolecule : public AtomContainer<QMAtom> {
 public:
  QMMolecule(std::string name, Index id) : AtomContainer<QMAtom>(name, id){};

  QMMolecule(CheckpointReader& r) : AtomContainer<QMAtom>(r){};
  void LoadFromFile(std::string filename);

  void WriteXYZ(std::string filename, std::string header) const;

  friend std::ostream& operator<<(std::ostream& out,
                                  const QMMolecule& container) {
    out << container.getId() << " " << container.getType() << "\n";
    for (const QMAtom& atom : container) {
      out << atom;
    }
    out << std::endl;
    return out;
  }
};

}  // namespace xtp
}  // namespace votca

#endif /* VOTCA_XTP_QMMOLECULE_H */

==> votca-xtp_2021.2.orig.tar.gz: xtp-2021.2/include/votca/xtp/qmmolecule.h <==
/*
 *            Copyright 2009-2020 The VOTCA Development Team
 *                       (http://www.votca.org)
 *
 *      Licensed under the Apache License, Version 2.0 (the "License")
 *
 * You may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *              http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */

#pragma once
#ifndef VOTCA_XTP_QMMOLECULE_H
#define VOTCA_XTP_QMMOLECULE_H

// Local VOTCA includes
#include "atomcontainer.h"
#include "qmatom.h"

namespace votca {
namespace xtp {

class QMMolecule : public AtomContainer<QMAtom> {
 public:
  QMMolecule(std::string name, Index id) : AtomContainer<QMAtom>(name, id){};

  QMMolecule(CheckpointReader& r) : AtomContainer<QMAtom>(r){};
  void LoadFromFile(std::string filename);

  void WriteXYZ(std::string filename, std::string header) const;

  void AddContainer(const AtomContainer<QMAtom>& container) {
    Index offset = _atomlist.size();
    _type += "_" + container.getType();
    for (const auto& at : container) {
      // Update atom IDs to make sure they are unique
      QMAtom atom(at.getId() + offset, at.getElement(), at.getPos());
      _atomlist.push_back(atom);
    }
    calcPos();
  }

  friend std::ostream& operator<<(std::ostream& out,
                                  const QMMolecule& container) {
    out << container.getId() << " " << container.getType() << "\n";
    for (const QMAtom& atom : container) {
      out << atom;
    }
    out << std::endl;
    return out;
  }
};

}  // namespace xtp
}  // namespace votca

#endif  // VOTCA_XTP_QMMOLECULE_H
